@@ -1,21 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*
 # pass import - Passwords importer swiss army knife
-# Copyright (C) 2017-2020 Alexandre PUJOL <alexandre@pujol.io>.
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
-#    the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
+# Copyright (C) 2017-2024 Alexandre PUJOL <alexandre@pujol.io>.
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 import io
 import os
@@ -31,6 +18,13 @@ from pass_import.tools import Config, get_magics
 
 MANAGERS = Managers()
 
+try:
+    import jsonpath_ng.ext
+    from jsonpath_ng.exceptions import JsonPathLexerError, JsonPathParserError
+    JSONNG = True
+except ImportError:
+    JSONNG = False
+
 
 class ArgParser(ArgumentParser):
     """Manages argument parsing and adds some defaults."""
@@ -123,6 +117,19 @@ class ArgParser(ArgumentParser):
             '--cols', action='store', default='',
             help='CSV expected columns to map columns to credential attributes'
                  '. Only used by the csv importer.')
+        extra.add_argument(
+            '--filter', dest='filter', metavar='FILTER', default=None,
+            help="""Export whole entries matching a JSONPath filter expression.
+                 Default: (none)
+                 This field can be:
+                  - a string JSONPath expression
+                  - an absolute path to a file containing a JSONPath filter
+                     expression.
+                 List of supported filter:
+                 https://github.com/h2non/jsonpath-ng
+                 Example:
+                  - '$.entries[*].tags[?@="Defaults"]' : Export only entries
+                 with a tag matching 'Defaults'""")
         extra.add_argument('--config', action='store', default='',
                            help="Set a config file. Default: '.import'")
 
@@ -383,7 +390,8 @@ def pass_import(conf, cls_import):
 
 def pass_export(conf, cls_export, data):
     """Insert cleaned data into the password repository."""
-    paths = []
+    paths_imported = []
+    paths_exported = []
     try:
         settings = conf.getsettings(conf['droot'], Cap.EXPORT)
         with cls_export(conf['out'], settings=settings) as exporter:
@@ -394,23 +402,57 @@ def pass_export(conf, cls_export, data):
                 pmpath = os.path.join(conf['droot'], entry.get(
                     'path', entry.get('title', '')))
                 conf.show(entry)
+                exported = pass_filter(conf, entry)
                 try:
-                    if not conf['dry_run']:
-                        exporter.insert(entry)
+                    if exported:
+                        if not conf['dry_run']:
+                            exporter.insert(entry)
                 except PMError as error:
                     conf.debug(traceback.format_exc())
                     conf.warning(f"Impossible to insert {pmpath} into "
                                  f"{conf['exporter']}: {error}")
                 else:
-                    paths.append(pmpath)
+                    paths_imported.append(pmpath)
+                    if exported:
+                        paths_exported.append(pmpath)
     except PMError as error:
         conf.debug(traceback.format_exc())
         conf.die(error)
 
-    return paths, report
+    return paths_imported, paths_exported, report
 
 
-def report(conf, paths, audit):
+def pass_filter(conf, entry):
+    """Filter entry based on a JSONPath filter expression."""
+    filter_expression = conf.get('filter', None)
+    if filter_expression is None:
+        return True
+
+    if not JSONNG:
+        message = ("--filter requires pass-import[filter] "
+                   "or pass-import[all] to be installed")
+        raise ImportError('Missing packages. ' + message)
+
+    # Having end users write their JSONPath filter expression as if
+    # pass-import processes/filters entries in bulk, will allow end
+    # users filter expression to continue to work when/if bulk filter is
+    # supported. Hence 'entries' being added
+    data = {'entries': [entry]}
+    try:
+        expr = jsonpath_ng.ext.parse(filter_expression)
+        matches = expr.find(data)
+        return len(matches) > 0
+    except (JsonPathLexerError, JsonPathParserError) as e:
+        conf.warning("Entry not exported due to error "
+                     "most likely in FILTER expression"
+                     + e.args[0])
+        if conf.verb >= 2:
+            conf.verbose("- Filter expression:" + filter_expression)
+            conf.verbose("- Entry: " + data)
+        return False
+
+
+def report(conf, paths_imported, paths_exported, audit):
     """Print final success report."""
     if conf['dry_run']:
         conf.warning(f"Data would be imported from {conf['importer']} "
@@ -424,7 +466,7 @@ def report(conf, paths, audit):
         conf.message(f"Root path: {conf['sroot']}")
     if conf['droot'] != '':
         conf.message(f"Root path: {conf['droot']}")
-    conf.message(f"Number of password imported: {len(paths)}")
+    conf.message(f"Number of password imported: {len(paths_imported)}")
     if conf['convert']:
         conf.message("Forbidden chars converted")
         conf.message(f"Path separator used: {conf['separator']}")
@@ -440,11 +482,16 @@ def report(conf, paths, audit):
     for entry in audit['duplicated']:
         conf.warning(f"Duplicated passwords detected: "
                      f"{', '.join([item['path'] for item in entry])}")
-    if paths:
-        conf.message("Passwords imported:")
-        paths.sort()
-        for path in paths:
-            conf.echo(path)
+
+    for paths, header in [
+        (paths_imported, "Passwords imported"),
+        (paths_exported, "Passwords exported")
+    ]:
+        if paths is not None:
+            conf.message(header + ": " + str(len(paths)))
+            paths.sort()
+            for path in paths:
+                conf.echo(path)
 
 
 def main():
@@ -462,10 +509,10 @@ def main():
 
     # Import & export
     data = pass_import(conf, cls_import)
-    paths, audit = pass_export(conf, cls_export, data)
+    paths_imported, paths_exported, audit = pass_export(conf, cls_export, data)
 
     # Success!
-    report(conf, paths, audit)
+    report(conf, paths_imported, paths_exported, audit)
 
 
 if __name__ == "__main__":
