@@ -1,11 +1,12 @@
 # -*- encoding: utf-8 -*-
 # pass import - Passwords importer swiss army knife
-# Copyright (C) 2017-2020 Alexandre PUJOL <alexandre@pujol.io>.
+# Copyright (C) 2017-2024 Alexandre PUJOL <alexandre@pujol.io>.
 #
 
 import getpass
 import os
 import sys
+from typing import Tuple, Dict, Union
 
 try:
     import magic
@@ -19,12 +20,12 @@ from pass_import import clean
 from pass_import.core import Cap
 
 
-def getpassword(path, name='Password'):
+def getpassword(path, name='Password') -> str:
     """Get the master password."""
     return getpass.getpass(f"{name} for {path}: ")
 
 
-def get_magics(path):
+def get_magics(path) -> Tuple[str, str]:
     """Get file format and encoding.
 
     The magic library is not really good at detecting text file-based format
@@ -119,7 +120,7 @@ class Config(dict):
         if self.quiet:
             self.verb = 0
 
-    def readconfig(self, args):
+    def readconfig(self, args: Dict[str, str]):
         """Read and merge config from args, config file and default."""
         configs = {}
         if os.path.isfile(args.get('config', '')):
@@ -133,6 +134,12 @@ class Config(dict):
         if os.path.isfile(configpath):
             with open(configpath, 'r') as file:
                 configs = yaml.safe_load(file)
+
+        filter_file = args.get('filter', None)
+        if filter_file is not None and os.path.isfile(filter_file):
+            with open(filter_file, mode='r') as f:
+                args['filter'] = f.read()
+
         self.merge(configs)
         self.merge(args)
         self.setclean()
@@ -156,7 +163,8 @@ class Config(dict):
             self['list_importers'] = self.get('list', False)
             self['list_exporters'] = False
 
-    def getsettings(self, root='', action=Cap.IMPORT):
+    def getsettings(self, root='', action=Cap.IMPORT
+                    ) -> Dict[str, Union[str, bool]]:
         """Return a curated setting dict for use in a manager class."""
         settings = {'action': action, 'root': root}
         keep = {
